package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaOrg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.huiju.estateagents.service.ITaPersonLevelSettingService;
import com.huiju.estateagents.entity.TaPersonLevelSetting;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 用户等级设置  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-11-05
 */

@Api(tags = "用户等级设置 ")
@RestController
@RequestMapping("/api")
public class TaPersonLevelSettingController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonLevelSettingController.class);

    @Autowired
    public ITaPersonLevelSettingService iTaPersonLevelSettingService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/person-level",method= RequestMethod.GET)
    // @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonLevelSettingList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String client,
                                                 @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                                 HttpServletRequest request) throws Exception {
        Integer orgId = getOrgId(request);

        IPage<TaPersonLevelSetting> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaPersonLevelSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id", orgId);
        queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
        queryWrapper.orderByAsc("level_id");

        IPage<TaPersonLevelSetting> result = iTaPersonLevelSettingService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPersonLevelSetting 实体对象
     * @return
     */
    @RequestMapping(value="/admin/person-level",method= RequestMethod.POST)
    // @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPersonLevelSettingAdd(@ApiParam("保存内容") @RequestBody TaPersonLevelSetting taPersonLevelSetting,
                                                HttpServletRequest request) throws Exception{
        if (null == taPersonLevelSetting) {
            return ResponseBean.error("未发现有效的数据", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null == taPersonLevelSetting.getLevelId()) {
            return ResponseBean.error("未设置等级ID", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taPersonLevelSetting.setOrgId(getOrgId(request));
        if (iTaPersonLevelSettingService.save(taPersonLevelSetting)){
            return ResponseBean.success(taPersonLevelSetting);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/person-level/{id}", method= RequestMethod.DELETE)
    // @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPersonLevelSettingDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        TaPersonLevelSetting taPersonLevelSetting = iTaPersonLevelSettingService.getById(id);
        taPersonLevelSetting.setStatus(CommConstant.STATUS_DELETE);
        return taPersonLevelSettingUpdate(id, taPersonLevelSetting);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPersonLevelSetting 实体对象
     * @return
     */
    @RequestMapping(value="/admin/person-level/{id}",method= RequestMethod.PUT)
    // @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPersonLevelSettingUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                                   @ApiParam("更新内容") @RequestBody TaPersonLevelSetting taPersonLevelSetting) throws Exception{
        taPersonLevelSetting.setLevelId(id);
        if (iTaPersonLevelSettingService.updateById(taPersonLevelSetting)){
            return ResponseBean.success(iTaPersonLevelSettingService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/person-level/{id}",method= RequestMethod.GET)
    // @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonLevelSettingGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPersonLevelSettingService.getById(id));
    }
}
